// pages/userCenter.js
const wxService = require('../../../../utils/wxService')
const util = require('../../../../utils/util')


wxService.page({
  /**
   * 页面的初始数据
   */
  data: {
    query: '',
    integralCouponList: [], // 积分兑换优惠券列表
    showDialog : false,
    dialogPicture : '',

  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();
    this.initIntegralCouponList();
  },
  
  // 获取优惠券活动列表
  initIntegralCouponList(refresh) {
    wx.showLoading({
      title: '加载中'
    });

    wxService.post(`/coupon/couponCenterActivity/buyer/getValidList`).then(res => {
      if (res) {
        let { result, data } = res.data
        if (result == 0) {
          wx.hideLoading();
          data = data ? data : [];
          data.forEach(item => {
            //判断活动开始时间是不是已经开始了
            item.isStart = true;
            //判断是不是老活动
            if(item.couponList){
              item.isStart = util.compareCurrentDate(item.startTime);
            }
          });

          this.data.integralCouponList = data;
          this.setData({
            integralCouponList: this.data.integralCouponList
          });
        }
      }

      if(refresh){
        wx.showToast({
          title: '刷新成功',
        });
        wx.stopPullDownRefresh();
      }

    }).finally(() => {
      wx.hideLoading();
    })
  },
  //立即兑换优惠券
  exchange(e) {
    wx.showLoading({
      title: '领取中..',
    });
    let isStart  = e.currentTarget.dataset.start;
    const { id } = e.currentTarget.dataset;
    let item =  e.currentTarget.dataset.item;
    //先判断是不是老的活动
    if(!item.couponList){
      this.getCoupon(id,item);
      return ;
    }

    if(isStart){
      this.getCoupon(id,item);
    }
    //预约
    else{
      this.orderCouponActivity(id,item);
    }
  },
  //立即领取
  getCoupon(id,item){
    wxService.post(`/coupon/couponCenterActivity/buyer/coupon/draw?id=${id}`).then(res => {
      wx.hideLoading();
      if(res){
        if(res.data.result == 0){
          //判断是不是老活动
          if(item.couponList){
            this.data.showDialog = true;
            this.data.dialogPicture = item.dialogPicture;
            this.setData({
              showDialog : this.data.showDialog,
              dialogPicture : this.data.dialogPicture
            });
          }
          else{
            wx.showToast({
              title: '领取成功!',
            });
          }
        }
        else{
          wx.showToast({
            title: '领取失败，请稍后再试',
            icon : 'none'
          });
        }
      }
    });
  },
  //立即预约
  orderCouponActivity(id){

  },

  //跳转到详情
  goCouponDetail(e) {
    const { id } = e.currentTarget.dataset
    wxService.router(`/subPackage/page/pages/couponCenterInfo/couponCenterInfo?id=${id}`)
  },
  /**
  * 页面相关事件处理函数--监听用户下拉动作
  */
  onPullDownRefresh: function () { 
    this.initIntegralCouponList(true);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {

  },
})